from invenio_records_permissions import RecordPermissionPolicy
from invenio_records_permissions.generators import SystemProcess, AnyUser


{% for b in python.record_permissions_bases %}
from {{ b|package_name }} import {{ b|base_name }}
{% endfor %}

class {{ python.record_permissions_class|base_name }}({% for b in python.record_permissions_bases %}{{ b|base_name }}, {% endfor %}RecordPermissionPolicy):
    """{{ python.record_class }} permissions."""

    can_search = [SystemProcess(), AnyUser()]
    can_read = [SystemProcess(), AnyUser()]
    can_create = [SystemProcess()]
    can_update = [SystemProcess()]
    can_delete = [SystemProcess()]
    can_manage = [SystemProcess()]
